@@ -26,7 +26,7 @@
 #include <glibtop/procstate.h>
 #if defined (__linux__)
 #include <asm/param.h>
-#elif defined(__OpenBSD__) || defined(__FreeBSD__) || defined(__FreeBSD_kernel__)
+#elif defined (__OpenBSD__)
 #include <sys/param.h>
 #include <sys/sysctl.h>
 #endif
@@ -114,13 +114,13 @@ fill_proc_properties (GtkWidget *tree, ProcInfo *info)
 
     get_process_memory_info(info);
 
-#if defined(__OpenBSD__) || defined(__FreeBSD__) || defined(__FreeBSD_kernel__)
+#if defined (__OpenBSD__)
     struct clockinfo cinf;
     size_t size = sizeof (cinf);
     int HZ;
     int mib[] = { CTL_KERN, KERN_CLOCKRATE };
 
-    if (sysctl (mib, nitems(mib), &cinf, &size, NULL, 0) == -1)
+    if (sysctl (mib, G_N_ELEMENTS (mib), &cinf, &size, NULL, 0) == -1)
         HZ = 100;
     else
         HZ = cinf.hz;
